:github_url: https://github.com/merlinquantum/merlin

.. _notebooks:

=========
Notebooks
=========

.. toctree::
   :maxdepth: 1
   :caption: Table of Contents

   FirstQuantumLayers
   Kernels
   iris_classification
   GanEtAl_q_gaussian_kernel
   GanEtAl_VQC_classification
   GanEtAl_VQC_fourier_series
   photonic_QCNN
    

